# TACTUS - model

> Threatening activities classification toward users' security

## Useful ressources

- [Write a better commit message](https://gist.github.com/MarcBresson/dd57a17f2ae60b6cb8688ee64cd7671d)
- [PEP 8 – Style Guide for Python Code](https://peps.python.org/pep-0008/)
